@@ -29,7 +29,6 @@
 #include <nm-device.h>
 #include <net/ethernet.h>
 #include <nm-access-point.h>
-#include <gnome-keyring.h>
 
 const char *utils_get_device_description (NMDevice *device);
 
@@ -47,16 +46,8 @@ char *utils_hash_ap (const GByteArray *ssid,
 
 char *utils_escape_notify_message (const char *src);
 
-#define KEYRING_UUID_TAG "connection-uuid"
-#define KEYRING_SN_TAG "setting-name"
-#define KEYRING_SK_TAG "setting-key"
-
-GnomeKeyringAttributeList *utils_create_keyring_add_attr_list (NMConnection *connection,
-                                                               const char *connection_uuid,
-                                                               const char *connection_id,
-                                                               const char *setting_name,
-                                                               const char *setting_key,
-                                                               char **out_display_name);
+char *utils_create_mobile_connection_id (const char *provider,
+                                         const char *plan_name);
 
 void utils_show_error_dialog (const char *title,
                               const char *text1,
